@@ -112,5 +112,6 @@ void dockwidget::getTranslation(const QString & szWord)
 	/* show popup window */
 	mypop->resize(myview->width()+3, myview->height()+3); // fit to size of myview
 	mypop->setMainWidget( myview );
-	mypop->popup( QPoint(x-w, y-h) );
+	//mypop->popup( QPoint(x-w, y-h) );
+	mypop->exec( QPoint(x-w, y-h) );
 }
